@@ -18,6 +18,7 @@ from LivestockCV.core import transform
 from LivestockCV.core.apply_mask import apply_mask
 from LivestockCV.core.crop import crop
 from LivestockCV.core.invert import invert
+from LivestockCV.core.rotate import rotate
 from LivestockCV.core import roi
 from LivestockCV.core import threshold
 from LivestockCV.core.gaussian_blur import gaussian_blur
@@ -33,4 +34,4 @@ from ._version import get_versions
 __version__ = get_versions()['version']
 del get_versions
 
-__all__ = ['fatal_error', 'Params', 'Outputs', 'deprecation_warning', 'print_image', 'plot_image', 'color_palette', 'rgb2gray', 'rgb2gray_hsv', 'rgb2gray_lab', 'transform', 'apply_mask', 'crop', 'invert', 'roi', 'threshold', 'gaussian_blur', 'analyze_color', 'frame_count', 'js_to_image', 'bbox_to_bytes','take_photo']
+__all__ = ['fatal_error', 'Params', 'Outputs', 'deprecation_warning', 'print_image', 'plot_image', 'color_palette', 'rgb2gray', 'rgb2gray_hsv', 'rgb2gray_lab', 'transform', 'apply_mask', 'crop', 'invert', 'rotate', 'roi', 'threshold', 'gaussian_blur', 'analyze_color', 'frame_count', 'js_to_image', 'bbox_to_bytes','take_photo']
