@@ -6,18 +6,7 @@ from LivestockCV.core import params
 
 
 def color_palette(num, saved=False):
-    """color_palette: Returns a list of colors length num
 
-    Inputs:
-    num        = number of colors to return.
-    saved      = use the previously stored color scale, if any (default = False).
-
-    Returns:
-    colors     = a list of color lists (RGB values)
-
-    :param num: int
-    :return colors: list
-    """
     # If a previous palette is saved and saved = True, return it
     if params.saved_color_scale is not None and saved is True:
         return params.saved_color_scale
