@@ -8,24 +8,20 @@ from LivestockCV.core import plot_image
 from LivestockCV.core import params
 
 
-def rotate(img, rotation_deg, crop):
+def rotate(img, rotation_deg):
 
     # Here we're going to input our parameters 
     iy, ix = np.shape(img)[:2]
     m = cv2.getRotationMatrix2D((ix / 2, iy / 2), rotation_deg, 1)
     cos = np.abs(m[0, 0])
     sin = np.abs(m[0, 1])
+    nw = int((iy * sin) + (ix * cos))
+    nh = int((iy * cos) + (ix * sin))
+    m[0, 2] += (nw / 2) - (ix / 2)
+    m[1, 2] += (nh / 2) - (iy / 2)
 
-    if not crop:
-        nw = int((iy * sin) + (ix * cos))
-        nh = int((iy * cos) + (ix * sin))
+    rotated_img = cv2.warpAffine(img, m, (nw, nh))
 
-        m[0, 2] += (nw / 2) - (ix / 2)
-        m[1, 2] += (nh / 2) - (iy / 2)
-
-        rotated_img = cv2.warpAffine(img, m, (nw, nh))
-    else:
-        rotated_img = cv2.warpAffine(img, m, (ix, iy))
 
     params.device += 1
 
